{% extends "basic/layout.html" %}




{%- block doctype -%}
<!DOCTYPE html>
{%- endblock %}

{%- block extrahead %}
<meta charset='utf-8'>

<meta http-equiv='X-UA-Compatible' content='IE=edge,chrome=1'>
<meta name='viewport' content='width=device-width, initial-scale=1.0, maximum-scale=1'>
<meta name="apple-mobile-web-app-capable" content="yes">

<link rel="stylesheet"
      href='https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css'/>

<link rel="stylesheet"
      href='//fonts.googleapis.com/css?family=Lato:300,500%'/>
{% endblock %}





{# Silence the sidebars, relbars #}
{% block header %}{% endblock %}
{% block relbar1 %}{% endblock %}
{% block relbar2 %}{% endblock %}
{% block sidebarsourcelink %}{% endblock %}



{% block body_tag %}
  <body data-spy="scroll" data-target="#localtoc" data-offset="100">
{%- endblock %}

{%- block content %}

{% include "navbar.html" %}

<div class="container-fluid" id="docs-container">
  
  <div class="row justify-content-md-left">
    <div class="col col-lg-2 order-1 order-xl-1 toc-left">
      {%- block sidebarleft %}
      <!-- {% include "searchbox.html" %} -->
      {% include "sidebar-left.html" %}
      {% endblock %}
    </div>

    <div class="col col-md-2 order-3 order-xl-2 toc-right">
      {%- block sidebar1 %}
      {% include "sidebar-right.html" %}
      {% endblock %}
    </div>
    
    <div class="col col-md-8 content order-2 order-xl-3 col-xl-7" >

      {% include "bannerversion.html" %}
      {% include "breadcrumbs.html" %}
      
      {% block body %}
      
      {% endblock %}
    </div>

  </div>
  
  {%- endblock %}

{%- block footer %}
  <footer class="footer">
    <div class="container-fluid">
      
      <p class="pull-right">
	<a href="#">Back to top</a>
	{% if theme_source_link_position == "footer" %}
        <br/>
        
	{% endif %}
      </p>
      <p>
	{%- if show_copyright %}
	{%- if hasdoc('copyright') %}
        {% trans path=pathto('copyright'), copyright=copyright|e %}&copy; <a href="{{ path }}">Copyright</a> {{ copyright }}.{% endtrans %}<br/>
	{%- else %}
        {% trans copyright=copyright|e %}&copy; Copyright {{ copyright }}.{% endtrans %}<br/>
	{%- endif %}
	{%- endif %}
	{%- if last_updated %}
	{% trans last_updated=last_updated|e %}Last updated on {{ last_updated }}.{% endtrans %}<br/>
	{%- endif %}
	{%- if show_sphinx %}
	{% trans sphinx_version=sphinx_version|e %}Created using <a href="http://sphinx-doc.org/">Sphinx</a> {{ sphinx_version }}.{% endtrans %}<br/>
	{%- endif %}
      </p>
    </div> 
  </footer>
  <script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.1/dist/umd/popper.min.js" integrity="sha384-9/reFTGAW83EW2RDu2S0VKaIzap3H66lZH81PoYlFhbGU+6BZp6G7niu735Sk7lN" crossorigin="anonymous"></script>
  
  <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"  crossorigin="anonymous"></script>

    <script>
    $(document).ready(function(){
	$("#localtoc a").addClass("nav-link")
	$('body').scrollspy({ target: '#localtoc' })
    });
  </script>
{%- endblock %}
