<li class="nav-item dropdown">
  <a role="button"
     class="nav-link dropdown-toggle"
     id="dLabelLocalToc"
     data-toggle="dropdown"
     data-target="#"
     href="#">{{ _(theme_navbar_pagenav_name) }}</a>
  <ul class="dropdown-menu localtoc"
      id="localtoc"
      role="menu"
      aria-labelledby="dLabelLocalToc">{{ toc }}</ul>
</li>
