<li class="nav-item dropdown globaltoc-container">
  <a role="button"
     class="nav-link dropdown-toggle"
     id="dLabelGlobalToc"
     data-toggle="dropdown"
     data-target="#"
     href="{{ pathto(master_doc) }}">
    Contents
  </a>
  <div class="dropdown-menu globaltoc"
      role="menu"
      aria-labelledby="dLabelGlobalToc">
    {{ toctree(maxdepth=theme_globaltoc_depth|toint, collapse=False, titles_only=True, includehidden=theme_globaltoc_includehidden|tobool) }}
  </div>
</li>
