{% if current_version and latest_version and current_version != latest_version %}
<div class="alert alert-primary" role="alert">
  {% if current_version.is_released %}
  You're reading an old version of this documentation.
  If you want up-to-date information, please have a look at <a href="{{ vpathto(latest_version.name) }}">{{latest_version.name}}</a>.
  {% else %}
  You're reading the documentation for a development version.
  For the latest released version, please have a look at <a href="{{ vpathto(latest_version.name) }}">{{latest_version.name}}</a>.
  {% endif %}
</div>
{% endif %}
