{%- if show_source and has_source and sourcename %}
<div id="sourcelink navbar-nav mr-auto hidden-sm">
  <a href="{{ pathto('_sources/' + sourcename, true)|e }}"
     rel="nofollow">{{ _('Source') }}</a>
</div>
{%- endif %}

