<header class="site-header">
  <nav class="">
    <!-- Brand and toggle get grouped for better mobile display -->
    <div class="sidebar bg-red">
      <a href="{{ pathto(master_doc) }}"><h1>{{ project| e }}</h1></a>
    </div>
    <p>&nbsp;</p>
  </nav>
</header>
