<div id="localtoc-wrapper">
  
  {%- if toc %}
  <div class="tocsection onthispage pt-5 pb-3">
    <i class="fas fa-list"></i> On this page
  </div>
  {%- endif %}
  
  <div id="localtoc">
    {{ toc }}
  </div>

</div>
